package com.zkqy.execution.produce.dispersed.mapper;

import com.zkqy.execution.produce.dispersed.entity.BpmExecuteNodeForm;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * 执行节点单Mapper接口
 * 
 * @author zkqy
 * @date 2023-12-07
 */
public interface BpmExecuteNodeFormMapper 
{
    /**
     * 查询执行节点单
     * 
     * @param id 执行节点单主键
     * @return 执行节点单
     */
    public BpmExecuteNodeForm selectBpmExecuteNodeFormById(Long id);

    /**
     * 查询执行节点单列表
     * 
     * @param bpmExecuteNodeForm 执行节点单
     * @return 执行节点单集合
     */
    public List<BpmExecuteNodeForm> selectBpmExecuteNodeFormList(BpmExecuteNodeForm bpmExecuteNodeForm);

    /**
     * 新增执行节点单
     * 
     * @param bpmExecuteNodeForm 执行节点单
     * @return 结果
     */
    public int insertBpmExecuteNodeForm(BpmExecuteNodeForm bpmExecuteNodeForm);

    /**
     * 修改执行节点单
     * 
     * @param bpmExecuteNodeForm 执行节点单
     * @return 结果
     */
    public int updateBpmExecuteNodeForm(BpmExecuteNodeForm bpmExecuteNodeForm);

    /**
     * 删除执行节点单
     * 
     * @param id 执行节点单主键
     * @return 结果
     */
    public int deleteBpmExecuteNodeFormById(Long id);

    /**
     * 批量删除执行节点单
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBpmExecuteNodeFormByIds(Long[] ids);

    /**
     * 当前发起的流程节点的表单信息
     *
     * @param processKey 流程编码
     * @return
     */
    public List<Map<String, String>> selectNodeFromInfos(String processKey);

    /**
     * 查询执行节点单详情
     *
     * @param bpmExecuteNodeForm 执行节点单
     * @return 执行节点单集合
     */
    BpmExecuteNodeForm selectBpmExecuteNodeFormInfo(BpmExecuteNodeForm bpmExecuteNodeForm);

    /**
     *  根据 taskProcessKey和 taskNodeKey查询当前节点执行的表单模版信息
     */
    public BpmExecuteNodeForm selectBpmExecuteNodeFormByTpKAndTnkAndTsk(@Param("taskProcessKey") String taskProcessKey, @Param("taskNodeKey") String taskNodeKey,  @Param("taskScriptKey") String taskScriptKey);

    /**
     * 根据tableSql查询这个sql对应的数据
     * @param tableSql
     * @return
     */
    public Map<String,String> tableSql(String tableSql);

    /**
     * 根据tableSql查询这个sql对应的数据(目前是查询表单下拉框数据在用)
     * @param tableSql
     * @return
     */
    public List<Map<String,Object>> executeSql(String tableSql);

    /**
     * 根据sqlKey查询tableSql数据
     * @param sqlKey
     * @return
     */
    public Map<String,String> getTableSqlBySqlKey(String sqlKey);

    /**
     * 根据sqlKey查询对应表单
     */
    public Map<String,String> getDfFormInfo();


}
